@@ -1,12 +1,30 @@
+# Copyright 2013 OpenStack LLC
+# All Rights Reserved.
+#
+#    Licensed under the Apache License, Version 2.0 (the "License"); you may
+#    not use this file except in compliance with the License. You may obtain
+#    a copy of the License at
+#
+#         http://www.apache.org/licenses/LICENSE-2.0
+#
+#    Unless required by applicable law or agreed to in writing, software
+#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#    License for the specific language governing permissions and limitations
+#    under the License.
+
 from cinderclient import client
+from cinderclient.v1 import availability_zones
 from cinderclient.v1 import limits
 from cinderclient.v1 import quota_classes
 from cinderclient.v1 import quotas
+from cinderclient.v1 import services
 from cinderclient.v1 import volumes
 from cinderclient.v1 import volume_snapshots
 from cinderclient.v1 import volume_types
 from cinderclient.v1 import volume_backups
 from cinderclient.v1 import volume_backups_restore
+from cinderclient.v1 import volume_transfers
 
 
 class Client(object):
@@ -45,6 +63,10 @@ class Client(object):
         self.quotas = quotas.QuotaSetManager(self)
         self.backups = volume_backups.VolumeBackupManager(self)
         self.restores = volume_backups_restore.VolumeBackupRestoreManager(self)
+        self.transfers = volume_transfers.VolumeTransferManager(self)
+        self.services = services.ServiceManager(self)
+        self.availability_zones = \
+            availability_zones.AvailabilityZoneManager(self)
 
         # Add in any extensions...
         if extensions:
@@ -83,3 +105,6 @@ class Client(object):
         credentials are wrong.
         """
         self.client.authenticate()
+
+    def get_volume_api_version_from_endpoint(self):
+        return self.client.get_volume_api_version_from_endpoint()
