@@ -17,8 +17,13 @@
 Volume snapshot interface (1.1 extension).
 """
 
-import urllib
+try:
+    from urllib import urlencode
+except ImportError:
+    from urllib.parse import urlencode
+
 from cinderclient import base
+import six
 
 
 class Snapshot(base.Resource):
@@ -34,6 +39,12 @@ class Snapshot(base.Resource):
         """
         self.manager.delete(self)
 
+    def update(self, **kwargs):
+        """
+        Update the display_name or display_description for this snapshot.
+        """
+        self.manager.update(self, **kwargs)
+
     @property
     def progress(self):
         return self._info.get('os-extended-snapshot-attributes:progress')
@@ -42,6 +53,10 @@ class Snapshot(base.Resource):
     def project_id(self):
         return self._info.get('os-extended-snapshot-attributes:project_id')
 
+    def reset_state(self, state):
+        """Update the snapshot with the privided state."""
+        self.manager.reset_state(self, state)
+
 
 class SnapshotManager(base.ManagerWithFind):
     """
@@ -89,11 +104,11 @@ class SnapshotManager(base.ManagerWithFind):
 
         qparams = {}
 
-        for opt, val in search_opts.iteritems():
+        for opt, val in six.iteritems(search_opts):
             if val:
                 qparams[opt] = val
 
-        query_string = "?%s" % urllib.urlencode(qparams) if qparams else ""
+        query_string = "?%s" % urlencode(qparams) if qparams else ""
 
         detail = ""
         if detailed:
@@ -109,3 +124,27 @@ class SnapshotManager(base.ManagerWithFind):
         :param snapshot: The :class:`Snapshot` to delete.
         """
         self._delete("/snapshots/%s" % base.getid(snapshot))
+
+    def update(self, snapshot, **kwargs):
+        """
+        Update the display_name or display_description for a snapshot.
+
+        :param snapshot: The :class:`Snapshot` to delete.
+        """
+        if not kwargs:
+            return
+
+        body = {"snapshot": kwargs}
+
+        self._update("/snapshots/%s" % base.getid(snapshot), body)
+
+    def reset_state(self, snapshot, state):
+        """Update the specified volume with the provided state."""
+        return self._action('os-reset_status', snapshot, {'status': state})
+
+    def _action(self, action, snapshot, info=None, **kwargs):
+        """Perform a snapshot action."""
+        body = {action: info}
+        self.run_hooks('modify_body_for_action', body, **kwargs)
+        url = '/snapshots/%s/action' % base.getid(snapshot)
+        return self.api.client.post(url, body=body)
