@@ -17,7 +17,11 @@
 Volume interface (1.1 extension).
 """
 
-import urllib
+try:
+    from urllib import urlencode
+except ImportError:
+    from urllib.parse import urlencode
+import six
 from cinderclient import base
 
 
@@ -87,8 +91,8 @@ class Volume(base.Resource):
     def upload_to_image(self, force, image_name, container_format,
                         disk_format):
         """Upload a volume to image service as an image."""
-        self.manager.upload_to_image(self, force, image_name, container_format,
-                                     disk_format)
+        return self.manager.upload_to_image(self, force, image_name,
+                                            container_format, disk_format)
 
     def force_delete(self):
         """Delete the specified volume ignoring its current state.
@@ -97,6 +101,19 @@ class Volume(base.Resource):
         """
         self.manager.force_delete(self)
 
+    def reset_state(self, state):
+        """Update the volume with the provided state."""
+        self.manager.reset_state(self, state)
+
+    def extend(self, volume, new_size):
+        """Extend the size of the specified volume.
+
+        :param volume: The UUID of the volume to extend
+        :param new_size: The desired size to extend volume to.
+        """
+
+        self.manager.extend(self, volume, new_size)
+
 
 class VolumeManager(base.ManagerWithFind):
     """
@@ -167,11 +184,11 @@ class VolumeManager(base.ManagerWithFind):
 
         qparams = {}
 
-        for opt, val in search_opts.iteritems():
+        for opt, val in six.iteritems(search_opts):
             if val:
                 qparams[opt] = val
 
-        query_string = "?%s" % urllib.urlencode(qparams) if qparams else ""
+        query_string = "?%s" % urlencode(qparams) if qparams else ""
 
         detail = ""
         if detailed:
@@ -326,3 +343,12 @@ class VolumeManager(base.ManagerWithFind):
 
     def force_delete(self, volume):
         return self._action('os-force_delete', base.getid(volume))
+
+    def reset_state(self, volume, state):
+        """Update the provided volume with the provided state."""
+        return self._action('os-reset_status', volume, {'status': state})
+
+    def extend(self, volume, new_size):
+        return self._action('os-extend',
+                            base.getid(volume),
+                            {'new_size': new_size})
